# REST API Connector

This is a pyATS connection class implementation that allows scripts to connect
to a device using REST via topology/YAML format.

The `rest.connector` module is abstraction enabled and currently supports
specific platforms. Please note that the custom abstraction keyword is required
in the `testbed.yaml` file.

This package is open sourced to [Cisco DevNet](https://developer.cisco.com/)
in June 2019.


# Installation

Installation guide can be found on [our website].

[our website]: https://developer.cisco.com/pyats/

```
$ pip install rest.connector
```

> Copyright (c) 2018 Cisco Systems, Inc. and/or its affiliates
